# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## [unreleased]
### Added
### Changed
### Fixed
### Removed
### Deprecated

## [v2.5.0] - 2025-10-16
### Added
- Support Python 3.14.
### Removed
- Remove Python 3.9 support.

## [v2.4.0] - 2024-11-02
### Removed
- Remove Python 3.8 support.

## [v2.3.3] - 2024-09-02
### Added
- Support Python 3.13.

## [v2.3.2] - 2024-02-03
### Added
- Support Python 3.12.
### Changed
- Update GitHub release action.

## [v2.3.1] - 2023-09-10
### Changed
- Print score info at end of visit.

## [v2.3.0] - 2023-09-05
### Fixed
- Prevent crash when reading from empty log file at very first invocation.
### Removed
- Remove Python 3.7 support.

## [v2.2.0] - 2023-02-07
### Added
- Fallback to using system media player if `simpleaudio` not available (configurable by environment variable `PYDARTZ_MEDIA_PLAYER`).
### Removed
- Remove Python 3.6 support.

## [v2.1.1] - 2023-01-08
### Changed
- Update suggestions for finishes.
- Officially support Python 3.11.

## [v2.1.0] - 2023-01-01
### Added
- Handle keyboard interrupt.
### Changed
- Display smaller banner for narrow terminals.
